==> symbol-processing-aa-embeddable-2.3.0-sources.jar: org/jetbrains/kotlin/fir/analysis/checkers/expression/FirTypeVisibilityHelpers.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.fir.analysis.checkers.expression

import ksp.org.jetbrains.kotlin.fir.analysis.checkers.context.CheckerContext
import ksp.org.jetbrains.kotlin.fir.isClassLikeVisible
import ksp.org.jetbrains.kotlin.fir.resolve.toClassSymbol
import ksp.org.jetbrains.kotlin.fir.symbols.SymbolInternals
import ksp.org.jetbrains.kotlin.fir.types.ConeKotlinType
import ksp.org.jetbrains.kotlin.fir.types.ConeKotlinTypeProjection
import ksp.org.jetbrains.kotlin.fir.visibilityChecker

@OptIn(SymbolInternals::class)
context(context: CheckerContext)
internal fun ConeKotlinType.isTypeVisibilityBroken(
    checkTypeArguments: Boolean,
): Boolean {

    val visibilityChecker = context.session.visibilityChecker
    val classSymbol = toClassSymbol()
    val containingFile = context.containingFileSymbol
    if (classSymbol == null || containingFile == null) return false
    if (
        !visibilityChecker.isClassLikeVisible(
            symbol = classSymbol,
            session = context.session,
            useSiteFileSymbol = containingFile,
            containingDeclarations = context.containingDeclarations
        )
    ) {
        return true
    }
    if (checkTypeArguments) {
        for (typeArgument in typeArguments) {
            if (typeArgument is ConeKotlinTypeProjection) {
                if (typeArgument.type.isTypeVisibilityBroken(checkTypeArguments = true)) return true
            }
        }
    }
    return false
}

==> symbol-processing-aa-embeddable-2.3.4-sources.jar: org/jetbrains/kotlin/fir/analysis/checkers/expression/FirTypeVisibilityHelpers.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.fir.analysis.checkers.expression

import ksp.org.jetbrains.kotlin.fir.analysis.checkers.context.CheckerContext
import ksp.org.jetbrains.kotlin.fir.isClassLikeVisible
import ksp.org.jetbrains.kotlin.fir.resolve.toClassSymbol
import ksp.org.jetbrains.kotlin.fir.symbols.SymbolInternals
import ksp.org.jetbrains.kotlin.fir.types.ConeKotlinType
import ksp.org.jetbrains.kotlin.fir.types.ConeKotlinTypeProjection
import ksp.org.jetbrains.kotlin.fir.visibilityChecker

@OptIn(SymbolInternals::class)
context(context: CheckerContext)
internal fun ConeKotlinType.isTypeVisibilityBroken(
    checkTypeArguments: Boolean,
): Boolean {

    val visibilityChecker = context.session.visibilityChecker
    val classSymbol = toClassSymbol(context.session)
    val containingFile = context.containingFileSymbol
    if (classSymbol == null || containingFile == null) return false
    if (
        !visibilityChecker.isClassLikeVisible(
            symbol = classSymbol,
            session = context.session,
            useSiteFileSymbol = containingFile,
            containingDeclarations = context.containingDeclarations
        )
    ) {
        return true
    }
    if (checkTypeArguments) {
        for (typeArgument in typeArguments) {
            if (typeArgument is ConeKotlinTypeProjection) {
                if (typeArgument.type.isTypeVisibilityBroken(checkTypeArguments = true)) return true
            }
        }
    }
    return false
}
